@@ -10,7 +10,7 @@ module Facter
           aix_expected_facts(agent)
         elsif agent['platform'] =~ /debian-/
           debian_expected_facts(agent)
-        elsif agent['platform'] =~ /el-|centos-/
+        elsif agent['platform'] =~ /amazon-|el-|centos-/
           el_expected_facts(agent)
         elsif agent['platform'] =~ /fedora-/
           fedora_expected_facts(agent)
@@ -79,9 +79,15 @@ module Facter
         if agent['platform'] =~ /amd64/
           os_arch     = 'amd64'
           os_hardware = 'x86_64'
+          processor_model_pattern = /(Intel\(R\).*)|(AMD.*)/
+        elsif agent['platform'] =~ /aarch64/
+          os_arch     = 'aarch64'
+          os_hardware = 'aarch64'
+          processor_model_pattern = // # FACT-3439 - facter doesn't figure out the processor type on these machines 
         else
           os_arch     = 'i386'
           os_hardware = 'i686'
+          processor_model_pattern = /(Intel\(R\).*)|(AMD.*)/
         end
 
         expected_facts = {
@@ -101,7 +107,7 @@ module Facter
           'processors.count' => /[1-9]/,
           'processors.physicalcount' => /[1-9]/,
           'processors.isa' => /unknown|#{os_hardware}/,
-          'processors.models' => /(Intel\(R\).*)|(AMD.*)/,
+          'processors.models' => processor_model_pattern,
           'kernel' => 'Linux',
           'kernelrelease' => /\d+\.\d+\.\d+/,
           'kernelversion' => /\d+\.\d+/,
@@ -144,11 +150,7 @@ module Facter
           os_distro_release_full = /#{os_version}\.\d+/
         else
           os_name = 'RedHat'
-          if '9'.match?(os_version) # FIXME: special case to be removed when ISO is updated to release ISO
-            os_distro_description = /Red Hat Enterprise Linux( Server)? release #{os_version}\.\d+ Beta \(\w+\)/
-          else
-            os_distro_description = /Red Hat Enterprise Linux( Server)? release #{os_version}\.\d+ \(\w+\)/
-          end
+          os_distro_description = /Red Hat Enterprise Linux( Server)? release #{os_version}\.\d+( Beta)? \(\w+\)/
           os_distro_id = /^RedHatEnterprise(Server)?$/
           os_distro_release_full = /#{os_version}\.\d+/
         end
@@ -177,7 +179,9 @@ module Facter
           expected_facts['os.distro.id'] = os_distro_id
           expected_facts['os.distro.release.full'] = os_distro_release_full
           expected_facts['os.distro.release.major'] = os_version
-          expected_facts['os.distro.release.minor'] = /\d/ if os_version != '2' # Amazon Linux 2
+          # Minor versions are not available in Amazon Linux < 2023 and has not
+          # yet been implemented in Facter for >= 2023
+          expected_facts['os.distro.release.minor'] = /\d/ unless os_name == 'Amazon'
           expected_facts['os.family'] = 'RedHat'
           expected_facts['os.hardware'] = os_hardware
           expected_facts['os.name'] = os_name
@@ -248,7 +252,7 @@ module Facter
           os_arch                 = 'arm64'
           os_hardware             = 'arm64'
           processors_isa          = 'arm'
-          processors_models       = /"Apple M1.*"/
+          processors_models       = /"Apple.*"/
         end
         expected_facts = {
           'os.architecture' => os_arch,
@@ -256,9 +260,12 @@ module Facter
           'os.hardware' => os_hardware,
           'os.name' => 'Darwin',
           'os.macosx.build' => /\d+[A-Z]\d{1,4}\w?/,
-          'os.macosx.product' => agent['platform'] =~ /osx-10/ ? 'Mac OS X' : 'macOS',
+          'os.macosx.product' => 'macOS',
           'os.macosx.version.major' => major_version,
           'os.macosx.version.minor' => /\d+/,
+          'os.macosx.version.patch' => /\d+/,
+          # If "patch" is 0, then the third component will be omitted
+          'os.macosx.version.full' => /^#{major_version}\.\d+(\.\d+)?$/,
           'os.release.full' => /\d+\.\d+\.\d+/,
           'os.release.major' => /\d+/,
           'os.release.minor' => /\d+/,
@@ -271,17 +278,6 @@ module Facter
           'kernelversion' => /\d+\.\d+\.\d+/,
           'kernelmajversion' => /\d+\.\d+/
         }
-
-        if agent['platform'] =~ /osx-10/
-          expected_facts['os.macosx.version.full'] = /#{expected_facts['os.macosx.version.major']}\.#{expected_facts['os.macosx.version.minor']}/
-        else
-          expected_facts['os.macosx.version.patch'] = /\d+/
-          if agent['platform'] =~ /arm64/
-            expected_facts['os.macosx.version.full'] = /^#{expected_facts['os.macosx.version.major']}\.#{expected_facts['os.macosx.version.minor']}$/
-          else
-            expected_facts['os.macosx.version.full'] = /^#{expected_facts['os.macosx.version.major']}\.#{expected_facts['os.macosx.version.minor']}\.*#{expected_facts['os.macosx.version.patch']}*$/
-          end
-        end
         expected_facts
       end
 
