@@ -153,7 +153,7 @@ class Installer
     # /System/Library/Frameworks/Ruby.framework/Versions/1.8/usr/bin
     # which is not generally where people expect executables to be installed
     # These settings are appropriate defaults for all OS X versions.
-    RbConfig::CONFIG['bindir'] = '/usr/bin' if RUBY_PLATFORM =~ /^universal-darwin[\d\.]+$/
+    RbConfig::CONFIG['bindir'] = '/usr/bin' if RUBY_PLATFORM =~ /^universal-darwin[\d.]+$/
 
     # if InstallOptions.configdir
     #   configdir = InstallOptions.configdir
@@ -208,11 +208,15 @@ class Installer
   # Join two paths. On Windows, dir must be converted to a relative path,
   # by stripping the drive letter, but only if the basedir is not empty.
   #
+  # We can't use endless ranges here because we still use older Rubies when building puppet-agent on older platforms
+  # (such as Solaris 10).
+  # rubocop:disable Style/SlicingWithRange
   def join(basedir, dir)
     return "#{basedir}#{dir[2..-1]}" if windows? && !basedir.empty? && (dir.length > 2)
 
     "#{basedir}#{dir}"
   end
+  # rubocop:enable Style/SlicingWithRange
 
   ##
   # Install file(s) from ./bin to RbConfig::CONFIG['bindir']. Patch it on the way
