@@ -1,6 +1,19 @@
 #! /usr/bin/env ruby
 # frozen_string_literal: true
 
+module FacterSpec
+  class SingleFactLoader
+    def initialize(name, value)
+      @name = name
+      @value = value
+    end
+
+    def load(collection)
+      collection.add(@name, value: @value)
+    end
+  end
+end
+
 describe LegacyFacter::Util::Collection do
   let(:external_loader) { instance_spy(LegacyFacter::Util::NothingLoader) }
   let(:internal_loader) do
@@ -91,8 +104,19 @@ describe LegacyFacter::Util::Collection do
       expect(fact.ldapname).to eq 'NewFact'
     end
 
+    it 'logs an error if the fact name contains the utf-8 null byte' do
+      name = "Uncool\0Name"
+      normalization_error = LegacyFacter::Util::Normalization::NormalizationError
+      expect(logger).to receive(:log_exception).with(an_instance_of(normalization_error)) do |exception|
+        expect(exception.message).to match(/contains a null byte reference/)
+      end
+      collection.define_fact(name)
+    end
+
     it 'logs an error if the fact could not be defined' do
-      expect(logger).to receive(:log_exception).with('Unable to add fact newfact: kaboom!')
+      expect(logger).to receive(:log_exception).with(RuntimeError) do |exception|
+        expect(exception.message).to equal('kaboom!')
+      end
 
       collection.define_fact(:newfact) do
         raise 'kaboom!'
@@ -101,20 +125,21 @@ describe LegacyFacter::Util::Collection do
   end
 
   describe 'when retrieving facts' do
-    before do
-      @fact = collection.add('YayNess')
-    end
+    let(:fact) { collection.add('YayNess') }
+
+    # initialize
+    before { fact }
 
     it 'returns the fact instance specified by the name' do
-      expect(collection.fact('YayNess')).to equal(@fact)
+      expect(collection.fact('YayNess')).to equal(fact)
     end
 
     it 'is case-insensitive' do
-      expect(collection.fact('yayness')).to equal(@fact)
+      expect(collection.fact('yayness')).to equal(fact)
     end
 
     it 'treats strings and symbols equivalently' do
-      expect(collection.fact(:yayness)).to equal(@fact)
+      expect(collection.fact(:yayness)).to equal(fact)
     end
 
     it 'uses its loader to try to load the fact if no fact can be found' do
@@ -267,7 +292,7 @@ describe LegacyFacter::Util::Collection do
     end
 
     it 'converts the fact name to a string' do
-      collection.each do |fact, _value|
+      collection.each do |fact, _value| # rubocop:disable Style/HashEachMethods
         expect(fact).to be_instance_of(String)
       end
     end
@@ -294,7 +319,7 @@ describe LegacyFacter::Util::Collection do
   end
 
   describe 'external facts' do
-    let(:external_loader) { SingleFactLoader.new(:test_fact, 'fact value') }
+    let(:external_loader) { FacterSpec::SingleFactLoader.new(:test_fact, 'fact value') }
     let(:collection) { LegacyFacter::Util::Collection.new(internal_loader, external_loader) }
 
     it 'loads when a specific fact is requested' do
@@ -377,11 +402,11 @@ describe LegacyFacter::Util::Collection do
       end
 
       it 'loads one fact' do
-        expect(collection.custom_facts.size). to eq(1)
+        expect(collection.custom_facts.size).to eq(1)
       end
 
       it 'loads the new fact' do
-        expect(collection.custom_facts.first[0]). to eq(:new_fact)
+        expect(collection.custom_facts.first[0]).to eq(:new_fact)
       end
     end
 
@@ -400,11 +425,11 @@ describe LegacyFacter::Util::Collection do
       end
 
       it 'loads one fact' do
-        expect(collection.custom_facts.size). to eq(1)
+        expect(collection.custom_facts.size).to eq(1)
       end
 
       it 'loads the new fact' do
-        expect(collection.custom_facts.first[0]). to eq(:new_fact)
+        expect(collection.custom_facts.first[0]).to eq(:new_fact)
       end
     end
   end
@@ -451,15 +476,4 @@ describe LegacyFacter::Util::Collection do
       end
     end
   end
-
-  class SingleFactLoader
-    def initialize(name, value)
-      @name = name
-      @value = value
-    end
-
-    def load(collection)
-      collection.add(@name, value: @value)
-    end
-  end
 end
