@@ -10,11 +10,6 @@ describe Facts::Aix::Networking::Fqdn do
       allow(Facter::Resolvers::Hostname).to receive(:resolve).with(:fqdn).and_return(value)
     end
 
-    it 'calls Facter::Resolvers::Hostname' do
-      fact.call_the_resolver
-      expect(Facter::Resolvers::Hostname).to have_received(:resolve).with(:fqdn)
-    end
-
     it 'returns fqdn fact' do
       expect(fact.call_the_resolver).to be_an_instance_of(Array).and \
         contain_exactly(an_object_having_attributes(name: 'networking.fqdn', value: value),
