@@ -10,11 +10,6 @@ describe Facts::Linux::Networking::Netmask do
       allow(Facter::Resolvers::Linux::Networking).to receive(:resolve).with(:netmask).and_return(value)
     end
 
-    it 'calls Facter::Resolvers::NetworkingLinux with netmask' do
-      fact.call_the_resolver
-      expect(Facter::Resolvers::Linux::Networking).to have_received(:resolve).with(:netmask)
-    end
-
     it 'returns netmask fact' do
       expect(fact.call_the_resolver).to be_an_instance_of(Array)
         .and contain_exactly(an_object_having_attributes(name: 'networking.netmask', value: value),
