@@ -10,11 +10,6 @@ describe Facts::Linux::Scope6Interfaces do
   describe '#call_the_resolver' do
     let(:interfaces) { { 'eth0' => { scope6: 'link' }, 'en1' => { scope6: 'global' } } }
 
-    it 'calls Facter::Resolvers::NetworkingLinux with interfaces' do
-      fact.call_the_resolver
-      expect(Facter::Resolvers::Linux::Networking).to have_received(:resolve).with(:interfaces)
-    end
-
     it 'returns legacy facts with scope6_<interface_name>' do
       expect(fact.call_the_resolver).to be_an_instance_of(Array).and \
         contain_exactly(an_object_having_attributes(name: 'scope6_eth0',
