@@ -12,11 +12,6 @@ describe Facts::Solaris::Memory::Swap::Total do
         receive(:resolve).with(:swap).and_return(value)
     end
 
-    it 'calls Facter::Resolvers::Solaris::Memory' do
-      fact.call_the_resolver
-      expect(Facter::Resolvers::Solaris::Memory).to have_received(:resolve).with(:swap)
-    end
-
     it 'returns swap total memory fact' do
       expect(fact.call_the_resolver).to be_an_instance_of(Array).and \
         contain_exactly(an_object_having_attributes(name: 'memory.swap.total', value: result),
