@@ -13,11 +13,6 @@ describe Facts::Solaris::Memory::System::TotalBytes do
         receive(:resolve).with(:system).and_return(resolver_output)
     end
 
-    it 'calls Facter::Resolvers::Solaris::Memory' do
-      fact.call_the_resolver
-      expect(Facter::Resolvers::Solaris::Memory).to have_received(:resolve).with(:system)
-    end
-
     it 'returns system total memory in bytes fact' do
       expect(fact.call_the_resolver).to be_an_instance_of(Array).and \
         contain_exactly(an_object_having_attributes(name: 'memory.system.total_bytes', value: value),
