@@ -11,11 +11,6 @@ describe Facts::Solaris::Timezone do
         receive(:resolve).with(:timezone).and_return(timezone)
     end
 
-    it 'calls Facter::Resolvers::Timezone' do
-      fact.call_the_resolver
-      expect(Facter::Resolvers::Timezone).to have_received(:resolve).with(:timezone)
-    end
-
     it 'returns a resolved fact' do
       expect(fact.call_the_resolver).to be_an_instance_of(Facter::ResolvedFact).and \
         have_attributes(name: 'timezone', value: timezone)
